package com.ruoyi.care.service;

import java.util.List;
import com.ruoyi.care.domain.CareNurses;

/**
 * 护理人员Service接口
 * 
 * @author qy
 * @date 2024-11-26
 */
public interface ICareNursesService 
{
    /**
     * 查询护理人员
     * 
     * @param nurseId 护理人员主键
     * @return 护理人员
     */
    public CareNurses selectCareNursesByNurseId(Long nurseId);

    /**
     * 查询护理人员列表
     * 
     * @param careNurses 护理人员
     * @return 护理人员集合
     */
    public List<CareNurses> selectCareNursesList(CareNurses careNurses);

    /**
     * 新增护理人员
     * 
     * @param careNurses 护理人员
     * @return 结果
     */
    public int insertCareNurses(CareNurses careNurses);

    /**
     * 修改护理人员
     * 
     * @param careNurses 护理人员
     * @return 结果
     */
    public int updateCareNurses(CareNurses careNurses);

    /**
     * 批量删除护理人员
     * 
     * @param nurseIds 需要删除的护理人员主键集合
     * @return 结果
     */
    public int deleteCareNursesByNurseIds(Long[] nurseIds);

    /**
     * 删除护理人员信息
     * 
     * @param nurseId 护理人员主键
     * @return 结果
     */
    public int deleteCareNursesByNurseId(Long nurseId);
}
